# setup.py
from setuptools import setup, find_packages

setup(
    name='flexiai',
    version='0.8.33',
    packages=find_packages(include=['flexiai', 'flexiai.*']),
    include_package_data=True,
    package_data={
        'flexiai': [
            'assistant/*.py',
            'config/*.py',
            'core/*.py',
            'core/utils/*.py',
            # 'docs/*.md',
            # 'examples/*.ipynb',
            # 'examples/*.py',
            # 'logs/*.log',
            # 'tests/*.py',
            # 'user_flexiai_rag/*.py',
            # 'user_flexiai_rag/data/*.csv',
            # '.env.template',
            # 'requirements.txt'
        ],
    },
    install_requires=[
        'annotated-types==0.7.0',
        'anyio==4.4.0',
        'asttokens==2.1.0',
        'azure-common==1.1.28',
        'azure-core==1.30.2',
        'azure-identity==1.17.1',
        'azure-mgmt-core==1.4.0',
        'azure-mgmt-resource==23.1.1',
        'backports.tarfile==1.2.0',
        'blinker==1.8.2',
        'certifi==2024.6.2',
        'cffi==1.16.0',
        'charset-normalizer==3.3.2',
        'click==8.1.7',
        'comm==0.1.3',
        'cryptography==42.0.8',
        'debugpy==1.6.5',
        'decorator==5.1.1',
        'distro==1.9.0',
        'docutils==0.21.2',
        'exceptiongroup==1.1.0',
        'executing==1.2.0',
        'Flask==3.0.3',
        'h11==0.14.0',
        'httpcore==1.0.5',
        'httpx==0.27.0',
        'idna==3.7',
        'importlib_metadata==6.8.0',
        'iniconfig==2.0.0',
        'ipykernel==6.24.0',
        'ipython==8.14.0',
        'ipywidgets==8.1.3',
        'isodate==0.6.1',
        'itsdangerous==2.2.0',
        'jaraco.classes==3.4.0',
        'jaraco.context==5.3.0',
        'jaraco.functools==4.0.1',
        'jedi==0.19.0',
        'jeepney==0.8.0',
        'jupyter_client==8.3.0',
        'jupyter_core==5.2.0',
        'jupyterlab_widgets==3.0.11',
        'keyring==25.2.1',
        'markdown-it-py==3.0.0',
        'MarkupSafe==2.1.5',
        'matplotlib-inline==0.1.6',
        'mdurl==0.1.2',
        'more-itertools==10.3.0',
        'msal==1.29.0',
        'msal-extensions==1.2.0',
        'nest_asyncio==1.5.7',
        'nh3==0.2.17',
        'numpy==2.0.0',
        'openai==1.35.0',
        'packaging==23.1',
        'pandas==2.2.2',
        'parso==0.8.3',
        'pexpect==4.8.0',
        'pickleshare==0.7.5',
        'pkginfo==1.10.0',
        'platformdirs==3.7.0',
        'pluggy==1.5.0',
        'portalocker==2.10.0',
        'prompt_toolkit==3.0.39',
        'psutil==5.9.5',
        'ptyprocess==0.7.0',
        'pure-eval==0.2.2',
        'pycparser==2.22',
        'pydantic==2.7.4',
        'pydantic-settings==2.3.3',
        'pydantic_core==2.18.4',
        'Pygments==2.15.1',
        'PyJWT==2.8.0',
        'pytest==8.2.2',
        'pytest-mock==3.14.0',
        'python-dateutil==2.8.2',
        'python-dotenv==1.0.1',
        'pytz==2024.1',
        'pyzmq==25.1.0',
        'readme_renderer==43.0',
        'requests==2.32.3',
        'requests-toolbelt==1.0.0',
        'rfc3986==2.0.0',
        'rich==13.7.1',
        'SecretStorage==3.3.3',
        'six==1.16.0',
        'sniffio==1.3.1',
        'stack-data==0.6.3',
        'tomli==2.0.1',
        'tornado==6.3.2',
        'tqdm==4.66.4',
        'traitlets==5.10.1',
        'twine==5.1.1',
        'typing_extensions==4.7.1',
        'tzdata==2024.1',
        'urllib3==2.2.2',
        'wcwidth==0.2.6',
        'Werkzeug==3.0.3',
        'widgetsnbextension==4.0.11',
        'zipp==3.17.0',
        'setuptools==70.2.0',
        'pip-audit==2.7.3',
    ],
    entry_points={
        'console_scripts': [
            # Define command line scripts here if needed
        ],
    },
    author='Savin Ionut Razvan',
    author_email='razvan.i.savin@gmail.com',
    description='FlexiAI is a versatile and powerful AI framework designed to streamline the integration and management \
                of OpenAI and Azure OpenAI services. With advanced Retrieval-Augmented Generation (RAG) capabilities,  \
                FlexiAI enables developers to build sophisticated AI-driven applications efficiently and effectively.',
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/SavinRazvan/flexiai',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development',
    ],
    python_requires='>=3.10',
    project_urls={
        'Bug Reports': 'https://github.com/SavinRazvan/flexiai/issues',
        'Source': 'https://github.com/SavinRazvan/flexiai',
    },
)